@@ -64,7 +64,8 @@ class TahrirDatabase(object):
             return badge_id
         return False
 
-    def add_badge(self, name, image, desc, criteria, issuer_id):
+    def add_badge(self, name, image, desc, criteria, issuer_id,
+                  tags=None):
         """
         Add a new badge to the database
 
@@ -79,6 +80,9 @@ class TahrirDatabase(object):
 
         :type issuer_id: int
         :param issuer_id: The ID of the issuer who issues this Badge
+
+        :type tags: str
+        :param tags: Comma-delimited list of badge tags.
         """
 
         badge_id = name.lower().replace(" ", "-")
@@ -88,7 +92,8 @@ class TahrirDatabase(object):
                               image=image,
                               description=desc,
                               criteria=criteria,
-                              issuer_id=issuer_id)
+                              issuer_id=issuer_id,
+                              tags=tags)
             self.session.add(new_badge)
             self.session.commit()
             return badge_id
@@ -188,15 +193,22 @@ class TahrirDatabase(object):
             return person_email
         return False
 
-    def add_person(self, email, nickname=None):
+    def add_person(self, email, nickname=None,
+                   website=None, bio=None):
         """
         Add a new Person to the database
 
-        :type person_id: int
-        :param person_id: This person's unique ID
+        :type email: str
+        :param email: This Person's email address
 
-        :type person_email: str
-        :param person_email: This Person's email address
+        :type nickname: str
+        :param nickname: This Person's nickname
+
+        :type website: str
+        :param website: This Person's website
+
+        :type website: str
+        :param bio: This Person's bio
         """
 
         if not self.person_exists(email=email):
@@ -206,9 +218,11 @@ class TahrirDatabase(object):
             if not nickname:
                 nickname = email.split('@')[0]
 
-            new_person = Person(email=email, nickname=nickname)
+            new_person = Person(email=email, nickname=nickname,
+                                website=website, bio=bio)
             self.session.add(new_person)
             self.session.commit()
+
             return email
         return False
 
